==> request-tracker4_4.4.4+dfsg.orig-third-party-source.tar.gz: rt-4.4.4/devel/third-party/ckeditor-src/plugins/link/lang/cs.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'cs', {
	acccessKey: 'Přístupový klíč',
	advanced: 'Rozšířené',
	advisoryContentType: 'Pomocný typ obsahu',
	advisoryTitle: 'Pomocný titulek',
	anchor: {
		toolbar: 'Záložka',
		menu: 'Vlastnosti záložky',
		title: 'Vlastnosti záložky',
		name: 'Název záložky',
		errorName: 'Zadejte prosím název záložky',
		remove: 'Odstranit záložku'
	},
	anchorId: 'Podle Id objektu',
	anchorName: 'Podle jména kotvy',
	charset: 'Přiřazená znaková sada',
	cssClasses: 'Třída stylu',
	emailAddress: 'E-mailová adresa',
	emailBody: 'Tělo zprávy',
	emailSubject: 'Předmět zprávy',
	id: 'Id',
	info: 'Informace o odkazu',
	langCode: 'Kód jazyka',
	langDir: 'Směr jazyka',
	langDirLTR: 'Zleva doprava (LTR)',
	langDirRTL: 'Zprava doleva (RTL)',
	menu: 'Změnit odkaz',
	name: 'Jméno',
	noAnchors: '(Ve stránce není definována žádná kotva!)',
	noEmail: 'Zadejte prosím e-mailovou adresu',
	noUrl: 'Zadejte prosím URL odkazu',
	other: '<jiný>',
	popupDependent: 'Závislost (Netscape)',
	popupFeatures: 'Vlastnosti vyskakovacího okna',
	popupFullScreen: 'Celá obrazovka (IE)',
	popupLeft: 'Levý okraj',
	popupLocationBar: 'Panel umístění',
	popupMenuBar: 'Panel nabídky',
	popupResizable: 'Umožňující měnit velikost',
	popupScrollBars: 'Posuvníky',
	popupStatusBar: 'Stavový řádek',
	popupToolbar: 'Panel nástrojů',
	popupTop: 'Horní okraj',
	rel: 'Vztah',
	selectAnchor: 'Vybrat kotvu',
	styles: 'Styl',
	tabIndex: 'Pořadí prvku',
	target: 'Cíl',
	targetFrame: '<rámec>',
	targetFrameName: 'Název cílového rámu',
	targetPopup: '<vyskakovací okno>',
	targetPopupName: 'Název vyskakovacího okna',
	title: 'Odkaz',
	toAnchor: 'Kotva v této stránce',
	toEmail: 'E-mail',
	toUrl: 'URL',
	toolbar: 'Odkaz',
	type: 'Typ odkazu',
	unlink: 'Odstranit odkaz',
	upload: 'Odeslat'
} );

==> request-tracker5_5.0.1+dfsg.orig-third-party-source.tar.gz: rt-5.0.1/devel/third-party/ckeditor-src/plugins/link/lang/cs.js <==
﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'cs', {
	acccessKey: 'Přístupový klíč',
	advanced: 'Rozšířené',
	advisoryContentType: 'Pomocný typ obsahu',
	advisoryTitle: 'Pomocný titulek',
	anchor: {
		toolbar: 'Záložka',
		menu: 'Vlastnosti záložky',
		title: 'Vlastnosti záložky',
		name: 'Název záložky',
		errorName: 'Zadejte prosím název záložky',
		remove: 'Odstranit záložku'
	},
	anchorId: 'Podle Id objektu',
	anchorName: 'Podle jména kotvy',
	charset: 'Přiřazená znaková sada',
	cssClasses: 'Třída stylu',
	download: 'Vynutit stažení',
	displayText: 'Zobrazit text',
	emailAddress: 'E-mailová adresa',
	emailBody: 'Tělo zprávy',
	emailSubject: 'Předmět zprávy',
	id: 'Id',
	info: 'Informace o odkazu',
	langCode: 'Kód jazyka',
	langDir: 'Směr jazyka',
	langDirLTR: 'Zleva doprava (LTR)',
	langDirRTL: 'Zprava doleva (RTL)',
	menu: 'Změnit odkaz',
	name: 'Jméno',
	noAnchors: '(Ve stránce není definována žádná kotva!)',
	noEmail: 'Zadejte prosím e-mailovou adresu',
	noUrl: 'Zadejte prosím URL odkazu',
	noTel: 'Vyplňte prosím telefonní číslo',
	other: '<jiný>',
	phoneNumber: 'Telefonní číslo',
	popupDependent: 'Závislost (Netscape)',
	popupFeatures: 'Vlastnosti vyskakovacího okna',
	popupFullScreen: 'Celá obrazovka (IE)',
	popupLeft: 'Levý okraj',
	popupLocationBar: 'Panel umístění',
	popupMenuBar: 'Panel nabídky',
	popupResizable: 'Umožňující měnit velikost',
	popupScrollBars: 'Posuvníky',
	popupStatusBar: 'Stavový řádek',
	popupToolbar: 'Panel nástrojů',
	popupTop: 'Horní okraj',
	rel: 'Vztah',
	selectAnchor: 'Vybrat kotvu',
	styles: 'Styl',
	tabIndex: 'Pořadí prvku',
	target: 'Cíl',
	targetFrame: '<rámec>',
	targetFrameName: 'Název cílového rámu',
	targetPopup: '<vyskakovací okno>',
	targetPopupName: 'Název vyskakovacího okna',
	title: 'Odkaz',
	toAnchor: 'Kotva v této stránce',
	toEmail: 'E-mail',
	toUrl: 'URL',
	toPhone: 'Telefon',
	toolbar: 'Odkaz',
	type: 'Typ odkazu',
	unlink: 'Odstranit odkaz',
	upload: 'Odeslat'
} );
